===============================
hashedindex
===============================

.. image:: https://img.shields.io/travis/MichaelAquilina/hashedindex.svg
        :target: https://travis-ci.org/MichaelAquilina/hashedindex

.. image:: https://img.shields.io/pypi/v/hashedindex.svg
        :target: https://pypi.python.org/pypi/hashedindex


InvertedIndex implementation using hash lists (dictionaries)

* Free software: BSD license
* Documentation: https://hashedindex.readthedocs.org.

Features
--------

* TODO
